<?php

/**
 * 下划线转驼峰
 * 思路:
 * step1.原字符串转小写,原字符串中的分隔符用空格替换,在字符串开头加上分隔符
 * step2.将字符串中每个单词的首字母转换为大写,再去空格,去字符串首部附加的分隔符.
 */
function camelize($uncamelized_words, $separator = '_')
{
    $uncamelized_words = $separator . str_replace($separator, " ", strtolower($uncamelized_words));
    return ltrim(str_replace(" ", "", ucwords($uncamelized_words)), $separator);
}

/**
 * 驼峰命名转下划线命名
 * 思路:
 * 小写和大写紧挨一起的地方,加上分隔符,然后全部转小写
 */
function uncamelize($camelCaps, $separator = '_')
{
    return strtolower(preg_replace('/([a-z])([A-Z])/', "$1" . $separator . "$2", $camelCaps));
}

/**
 * 防sql注入字符串转义
 * @param $content 要转义内容
 * @return array|string
 */
function escapeString($content)
{
    $pattern = "/(select[\s])|(insert[\s])|(update[\s])|(delete[\s])|(from[\s])|(where[\s])|(drop[\s])/i";
    if (is_array($content)) {
        foreach ($content as $key => $value) {
            $content[$key] = addslashes(trim($value));
            if (preg_match($pattern, $content[$key])) {
                // echo $content[$key];
                $content[$key] = '';
            }
        }
    } else {
        $content = addslashes(trim($content));
        if (preg_match($pattern, $content)) {
            $content = '';
        }
    }
    return $content;
}

/**
 * 去除 input表单中的空格等
 */
function handleInput($data)
{
    $data = trim($data);
    $data = stripslashes($data);
    $data = htmlspecialchars($data);
    return $data;
}

/**
 * json 格式输出对象
 */
function print_json($data)
{
    $res = json_encode($data, JSON_PRETTY_PRINT);
    if (IS_CLI) {
        echo $res;
    } else {
        // 替换空格和换行符
        $res = str_replace(' ', '&nbsp;', $res);
        $res = str_replace("\n", '<br>', $res);
        echo $res;
    }
}

/**
 * 将数值金额转换为中文大写金额
 * @param $amount float 金额(支持到分)
 * @param $type   int   补整类型,0:到角补整;1:到元补整
 * @return mixed 中文大写金额
 */
function convertAmountToCn($amount, $type = 1)
{
    // 判断输出的金额是否为数字或数字字符串
    if (!is_numeric($amount)) {
        return "要转换的金额只能为数字!";
    }

    // 金额为0,则直接输出"零元整"
    if ($amount == 0) {
        return "人民币零元整";
    }

    // 金额不能为负数
    if ($amount < 0) {
        return "要转换的金额不能为负数!";
    }

    // 金额不能超过万亿,即12位
    if (strlen($amount) > 12) {
        return "要转换的金额不能为万亿及更高金额!";
    }

    // 预定义中文转换的数组
    $digital = array('零', '壹', '贰', '叁', '肆', '伍', '陆', '柒', '捌', '玖');
    // 预定义单位转换的数组
    $position = array('仟', '佰', '拾', '亿', '仟', '佰', '拾', '万', '仟', '佰', '拾', '元');

    // 将金额的数值字符串拆分成数组
    $amountArr = explode('.', $amount);

    // 将整数位的数值字符串拆分成数组
    $integerArr = str_split($amountArr[0], 1);

    // 将整数部分替换成大写汉字
    //    $result = '人民币';
    $result = '';
    $integerArrLength = count($integerArr);     // 整数位数组的长度
    $positionLength = count($position);         // 单位数组的长度
    $zeroCount = 0;                             // 连续为0数量
    for ($i = 0; $i < $integerArrLength; $i++) {
        // 如果数值不为0,则正常转换
        if ($integerArr[$i] != 0) {
            // 如果前面数字为0需要增加一个零
            if ($zeroCount >= 1) {
                $result .= $digital[0];
            }
            $result .= $digital[$integerArr[$i]] . $position[$positionLength - $integerArrLength + $i];
            $zeroCount = 0;
        } else {
            $zeroCount += 1;
            // 如果数值为0, 且单位是亿,万,元这三个的时候,则直接显示单位
            if (($positionLength - $integerArrLength + $i + 1) % 4 == 0) {
                $result = $result . $position[$positionLength - $integerArrLength + $i];
            }
        }
    }

    // 如果小数位也要转换
    if ($type == 0) {
        // 将小数位的数值字符串拆分成数组
        $decimalArr = str_split($amountArr[1], 1);
        // 将角替换成大写汉字. 如果为0,则不替换
        if ($decimalArr[0] != 0) {
            $result = $result . $digital[$decimalArr[0]] . '角';
        }
        // 将分替换成大写汉字. 如果为0,则不替换
        if ($decimalArr[1] != 0) {
            $result = $result . $digital[$decimalArr[1]] . '分';
        }
    } else {
        $result = $result . '整';
    }
    return $result;
}
